@@ -9,7 +9,7 @@ require 5.010000;
 
 use feature 'state';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp;
 
@@ -19,7 +19,7 @@ use Ref::Util qw< is_arrayref is_ref is_coderef  >;
 
 use custom::failures;
 use Package::Stash;
-use Hash::Wrap;
+use Hash::Wrap { -as => '_wrap_hash' };
 
 use PDL::Algorithm::Center::Failure ':all';
 
@@ -42,7 +42,8 @@ sub _weighted_mean_center {
 
     $total_weight //= $wmask->dsum;
 
-    iteration_empty_failure->throw( "weighted mean center: all elements excluded or sum(weight) == 0" )
+    iteration_empty_failure->throw(
+        "weighted mean center: all elements excluded or sum(weight) == 0" )
       if $total_weight == 0;
 
     return ( $coords * $wmask->dummy( 0 ) )->xchg( 0, 1 )->dsumover
@@ -73,7 +74,8 @@ sub _sigma_clip_initialize {
     $current->total_weight( $wmask->dsum );
     $current->nelem( $mask->sum );
 
-    iteration_empty_failure->throw( "sigma_clip initialize: all elements excluded or sum(weight) == 0" )
+    iteration_empty_failure->throw(
+        "sigma_clip initialize: all elements excluded or sum(weight) == 0" )
       if $current->total_weight == 0;
 
     $current->{sigma} = sqrt( ( $wmask * $r2 )->dsum / $current->total_weight );
@@ -98,7 +100,8 @@ sub _sigma_clip_calc_wmask {
     my $wmask = $work->{wmask};
     $wmask .= $mask * $weight;
 
-    iteration_empty_failure->throw( "sigma_clip calc_wmask: all elements excluded or sum(weight) == 0" )
+    iteration_empty_failure->throw(
+        "sigma_clip calc_wmask: all elements excluded or sum(weight) == 0" )
       if $iter->total_weight == 0;
 
     $iter->sigma( sqrt( ( $wmask * $r2 )->dsum / $iter->total_weight ) );
@@ -165,8 +168,8 @@ sub _sigma_clip_log_iteration {
 
     printf(
         join( ' ', @fmt ) . "\n",
-        $iter->iter, $iter->nelem, $iter->total_weight,
-        $iter->clip // 'undef', $iter->sigma, $iter->center->list
+        $iter->iter, $iter->nelem, $iter->total_weight, $iter->clip // 'undef',
+        $iter->sigma, $iter->center->list
     );
 }
 
@@ -447,35 +450,33 @@ sub _sigma_clip_log_iteration {
 #pod =cut
 
 use Hash::Wrap ( {
-    -as     => 'new_iteration',
-    -create => 1,
-    -class  => 'PDL::Algorithm::Center::Iteration',
-    -clone  => sub {
-        my $hash = shift;
+        -as     => '_new_iteration',
+        -class  => 'PDL::Algorithm::Center::Iteration',
+        -clone  => sub {
+            my $hash = shift;
 
-        return {
-            map {
-                my $value = $hash->{$_};
-                $value = $value->copy if $value->$_isa( 'PDL' );
-                ( $_, $value )
-            } keys %$hash
-        };
+            return {
+                map {
+                    my $value = $hash->{$_};
+                    $value = $value->copy if $value->$_isa( 'PDL' );
+                    ( $_, $value )
+                } keys %$hash
+            };
+        },
     },
-  },
-  {
-    -as     => 'return_iterate_results',
-    -class  => 'PDL::Algorithm::Center::Iterate::Results',
-    -create => 1,
-  } );
+    {
+        -as     => '_return_iterate_results',
+        -class  => 'PDL::Algorithm::Center::Iterate::Results',
+    } );
 
 
 sub sigma_clip {
 
     state $check = compile_named(
-        center      => Optional [ ArrayRef [ Num | Undef ] | Center | CodeRef ],
-        clip        => Optional [PositiveNum],
-        coords      => Optional [Coords],
-        dtol        => PositiveNum,
+        center => Optional [ ArrayRef [ Num | Undef ] | Center | CodeRef ],
+        clip   => Optional [PositiveNum],
+        coords => Optional [Coords],
+        dtol   => PositiveNum,
         iterlim     => Optional [PositiveInt],
         log         => Optional [ Bool | CodeRef ],
         mask        => Optional [ Undef | Piddle_min1D_ne ],
@@ -489,11 +490,11 @@ sub sigma_clip {
     my @argv = @_;
     try {
         my %opt = %{ $check->( @argv ); };
-        $opt = wrap_hash( \%opt );
+        $opt = _wrap_hash( \%opt );
     }
-      catch {
-          parameter_failure->throw( $_ );
-      };
+    catch {
+        parameter_failure->throw( $_ );
+    };
 
     $opt->{iterlim} //= 10;
 
@@ -1150,7 +1151,7 @@ sub iterate {
         save_weight  => Optional [Bool],
     );
 
-    my $opt = wrap_hash( $check->( @_ ) );
+    my $opt = _wrap_hash( $check->( @_ ) );
 
     $opt->{log}         //= undef;
     $opt->{save_mask}   //= 0;
@@ -1173,7 +1174,7 @@ sub iterate {
     my $total_weight;
 
     if ( defined $opt->mask ) {
-        $nelem = $opt->mask->sum;
+        $nelem        = $opt->mask->sum;
         $total_weight = ( $opt->mask * $opt->weight )->dsum;
     }
     else {
@@ -1201,12 +1202,12 @@ sub iterate {
 
     my @iteration;
 
-    my $work   = {};
+    my $work = {};
 
     # Set up initial state
 
     push @iteration,
-      new_iteration( {
+      _new_iteration( {
           center       => $opt->center,
           total_weight => $total_weight,
           nelem        => $nelem,
@@ -1222,15 +1223,17 @@ sub iterate {
 
     eval {
 
-        $opt->initialize->( $opt->coords, $mask, $weight, $iteration[-1], $work );
+        $opt->initialize->(
+            $opt->coords, $mask, $weight, $iteration[-1], $work
+        );
 
-        $opt->log && $opt->log->( new_iteration( $iteration[-1] ) );
+        $opt->log && $opt->log->( _new_iteration( $iteration[-1] ) );
 
         while ( !$converged && ++$iteration <= $opt->iterlim ) {
 
             my $last = $iteration[-1];
 
-            my $current = new_iteration( $last );
+            my $current = _new_iteration( $last );
             push @iteration, $current;
 
             ++$current->{iter};
@@ -1243,7 +1246,8 @@ sub iterate {
 
             $opt->calc_wmask->( $opt->coords, $mask, $weight, $current, $work );
 
-            $current->total_weight( ( $mask * $weight ) ->dsum ) unless defined $current->total_weight;
+            $current->total_weight( ( $mask * $weight )->dsum )
+              unless defined $current->total_weight;
             $current->nelem( $mask->sum )
               unless defined $current->nelem;
 
@@ -1251,13 +1255,15 @@ sub iterate {
               if $current->nelem == 0;
 
             $current->center(
-                $opt->calc_center->( $opt->coords, $mask, $weight, $current, $work ) );
+                $opt->calc_center->(
+                    $opt->coords, $mask, $weight, $current, $work
+                ) );
 
             $converged = $opt->is_converged->(
                 $opt->coords, $mask, $weight, $last, $current, $work
             );
 
-            $opt->log && $opt->log->( new_iteration( $current ) );
+            $opt->log && $opt->log->( _new_iteration( $current ) );
         }
 
     };
@@ -1269,9 +1275,9 @@ sub iterate {
         msg => "iteration limit (@{[ $opt->iterlim ]}) reached" )
       if $iteration > $opt->iterlim;
 
-    return_iterate_results( {
+    _return_iterate_results( {
         %{ $iteration[-1] },
-        ( $opt->save_mask ? ( mask => $mask ) : () ),
+        ( $opt->save_mask   ? ( mask   => $mask )   : () ),
         ( $opt->save_weight ? ( weight => $weight ) : () ),
         iterations => \@iteration,
         success    => !$error,
@@ -1302,7 +1308,7 @@ PDL::Algorithm::Center - Various methods of finding the center of a sample
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
